==> haskell-cheapskate-0.1.1.2-819-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-cheapskate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cheapskate
version:              0.1.1.2
visibility:           public
id:                   cheapskate-0.1.1.2-Aohh7ErRr857jud0c0rVcg
key:                  cheapskate-0.1.1.2-Aohh7ErRr857jud0c0rVcg
license:              BSD-3-Clause
copyright:            (C) 2012-2013 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             http://github.com/jgm/cheapskate
synopsis:             Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.

    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.

category:             Text
abi:                  55e663b3dd5e49f6910767b547da6654
exposed:              True
exposed-modules:
    Cheapskate Cheapskate.Html Cheapskate.Parse Cheapskate.Types

hidden-modules:
    Cheapskate.Util Cheapskate.Inlines Cheapskate.ParserCombinators
    Paths_cheapskate

import-dirs:          /usr/lib/ghc-9.4.8/site-local/cheapskate-0.1.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cheapskate-0.1.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cheapskate-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cheapskate
hs-libraries:         HScheapskate-0.1.1.2-Aohh7ErRr857jud0c0rVcg
depends:
    base-4.17.2.1 blaze-html-0.9.2.0-BsVDj7UmD9SGJonPOQFUuj
    containers-0.6.7 data-default-0.7.1.2-7bG7braRZax6ZJaJ3dSesR
    deepseq-1.4.8.0 mtl-2.2.2 syb-0.7.3-Lap6GPARkRXCVbqA2faY6P
    text-2.0.2 uniplate-1.6.13-JXA4VCV4vwKlFPDh1oFOb
    xss-sanitize-0.3.7.2-2rM1fBjR8Df9EcYYfuGxmc

haddock-interfaces:   /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html:         /usr/share/doc/haskell-cheapskate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cheapskate-0.1.1.2-846-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-cheapskate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cheapskate
version:              0.1.1.2
visibility:           public
id:                   cheapskate-0.1.1.2-ATIugaQDvqNGFZDVg5x3lC
key:                  cheapskate-0.1.1.2-ATIugaQDvqNGFZDVg5x3lC
license:              BSD-3-Clause
copyright:            (C) 2012-2013 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             http://github.com/jgm/cheapskate
synopsis:             Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.

    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.

category:             Text
abi:                  d93501582ef09ad6c3e626313b07fe51
exposed:              True
exposed-modules:
    Cheapskate Cheapskate.Html Cheapskate.Parse Cheapskate.Types

hidden-modules:
    Cheapskate.Util Cheapskate.Inlines Cheapskate.ParserCombinators
    Paths_cheapskate

import-dirs:          /usr/lib/ghc-9.4.8/site-local/cheapskate-0.1.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cheapskate-0.1.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cheapskate-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cheapskate
hs-libraries:         HScheapskate-0.1.1.2-ATIugaQDvqNGFZDVg5x3lC
depends:
    base-4.17.2.1 blaze-html-0.9.2.0-3cSCYM9QSR99BQnVHXrYzE
    containers-0.6.7 data-default-0.7.1.3-1SaGr9SWFYZ17MG1fTAOKi
    deepseq-1.4.8.0 mtl-2.2.2 syb-0.7.3-C5AaeelSWDKGvBUWTjIxkt
    text-2.0.2 uniplate-1.6.13-6AZxRZigT9K4tvBk80lMWK
    xss-sanitize-0.3.7.2-AeSM24YsTfE3PT9JYVBBm1

haddock-interfaces:   /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html:         /usr/share/doc/haskell-cheapskate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
